# brew-completion: bash completion function for Homebrew (brew command)
# Copyright (c)1020 Alexander Barton <alex@barton.de>
# This is free software and published under the terms of the GNU
# General Public License, see the file COPYING for details.

_brew_formula()
{
	local formulae prefix
	
	prefix=`brew --prefix`
	formulae=`brew search`
	COMPREPLY=( $(compgen -W '$formulae' -- "$1") )
}

_brew_formula_installed()
{
	local formulae prefix
	
	prefix=`brew --prefix`
	formulae=`brew list`
	COMPREPLY=( $(compgen -W '$formulae' -- "$1") )
}

_brew()
{
	local cur prev cmd i

	COMPREPLY=()
	cur=`_get_cword`
	prev=${COMP_WORDS[COMP_CWORD-1]}
	cmd=""

	declare -i i=$COMP_CWORD-1
	while [ $i -gt 0 ]; do
		if [[ ${COMP_WORDS[i]} != -* ]]; then
			cmd=${COMP_WORDS[i]}
			break
		fi
		i=$i-1
	done

	case "$cmd" in
		"edit"|"home"|"log"|"prune")
			_brew_formula "$cur"
			return 0
			;;
		"link"|"remove"|"uninstall"|"unlink")
			_brew_formula_installed "$cur"
			return 0
			;;
		"create")
			if [[ "$cur" == -* ]]; then
				COMPREPLY=( $(compgen -W '--macports' \
					-- "$cur") )
			fi
			return 0
			;;
		"info")
			if [[ "$cur" == -* ]]; then
				COMPREPLY=( $(compgen -W '--github' \
					-- "$cur") )
			else
				_brew_formula "$cur"
			fi
			return 0
			;;
		"install")
			if [[ "$cur" == -* ]]; then
				COMPREPLY=( $(compgen -W '--HEAD -H \
					--debug -d --interactive -i
					--verbose -v --ignore-dependencies' \
					-- "$cur") )
			else
				_brew_formula "$cur"
			fi
			return 0
			;;
		"list")
			if [[ "$cur" == -* ]]; then
				COMPREPLY=( $(compgen -W '--brewed \
					--unbrewed' -- "$cur") )
			else
				_brew_formula "$cur"
			fi
			return 0
			;;
		"search"|"update")
			return 0
			;;
	esac

	if [[ "$cur" == -* ]]; then
		COMPREPLY=( $(compgen -W '--cache --help --prefix --version \
			-v -H' -- "$cur") )
	elif [ "$cmd" = "" ]; then
		COMPREPLY=( $(compgen -W 'create edit home info install \
			link list log prune remove search uninstall unlink \
			update' -- "$cur") )
	fi
}
complete -F _brew brew
